@@ -24,10 +24,8 @@
 #include "ktrm.h"
 #include <config-juk.h>
 
-#ifdef HAVE_TUNEPIMP //Silence warning about HAVE_TUNEPIMP not being defined.
-#if HAVE_TUNEPIMP
+#if (HAVE_TUNEPIMP > 0)
 
-#include <k3resolver.h>
 #include <kprotocolmanager.h>
 #include <kurl.h>
 #include <kdebug.h>
@@ -169,7 +167,7 @@ protected:
             // Check what hosts are allowed to proceed without being proxied,
             // or if using reversed proxy, what hosts must be proxied.
             foreach(const QString &host, noProxies) {
-                QString normalizedHost = KNetwork::KResolver::normalizeDomain(host);
+                const QString normalizedHost(KUrl::fromAce(KUrl::toAce(host)));
 
                 if(normalizedHost == tunepimpHost ||
                    tunepimpHost.endsWith('.' + normalizedHost))
@@ -196,7 +194,7 @@ protected:
                 KUrl proxy = KProtocolManager::proxyFor("http");
                 QString proxyHost = proxy.host();
 
-                kDebug(65432) << "Using proxy server " << proxyHost << " for www.musicbrainz.org.\n";
+                kDebug() << "Using proxy server " << proxyHost << " for www.musicbrainz.org.\n";
                 tp_SetProxy(m_pimp, proxyHost.toAscii(), short(proxy.port()));
             }
         }
@@ -631,7 +629,7 @@ void KTRMLookup::puidGenerated()
     d->results.clear();
 
     KIO::Job *job = KIO::storedGet( QString( "http://musicbrainz.org/ws/1/track/?type=xml&puid=%1" ).arg( puid ) , KIO::NoReload, KIO::HideProgressInfo );
-    connect( job, SIGNAL( result( KJob* ) ), SLOT( lookupResult( KJob* ) ) );
+    connect( job, SIGNAL(result(KJob*)), SLOT(lookupResult(KJob*)) );
 #endif
 }
 
@@ -770,7 +768,6 @@ double stringSimilarity(QString s1, QString s2)
     return l3 ? nCommon * 2.0 / l3 : 1.0;
 }
 
-#endif
-#endif
+#endif // (HAVE_TUNEPIMP > 0)
 
 // vim: set et sw=4 tw=0 sta:
